@@ -408,6 +408,8 @@ def iter_branch_tree(t, lister=None):
 def open_from_url(location):
     location = urlutils.normalize_url(location)
     dirname, basename = urlutils.split(location)
+    if location.endswith('/') and not basename.endswith('/'):
+        basename += '/'
     return get_transport(dirname).get(basename)
 
 
