@@ -28,7 +28,7 @@ class GhostFetcher(object):
                 raise BzrCommandError('No branch specified and no location'
                                       ' saved.')
             else:
-                note("Using saved location %s.", branch)
+                note("Using saved location %s.", other)
         other_branch = Branch.open_containing(other)[0]
         return klass(this_branch, other_branch)
 
