@@ -6,9 +6,16 @@ from bzrlib import branch, osutils, workingtree
 from bzrlib.config import LocationConfig
 from bzrlib.transport import get_transport
 from bzrlib.tests import TestCaseWithTransport, HardlinkFeature
+from bzrlib.plugins.bzrtools import command
 
 
 class TestBzrTools(TestCaseWithTransport):
+
+    def setUp(self):
+        TestCaseWithTransport.setUp(self)
+        command._testing = True
+        self.addCleanup(command._stop_testing)
+
     @staticmethod
     def touch(filename):
         file(filename, 'wb').write('')
